@@ -17,7 +17,7 @@ class Constraint(metaclass=ABCMeta):
     def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
         pass
 
-    def get_error(self, schedule: "Schedule", chunk: "Chunk") -> str:
+    def geterror(self, schedule: "Schedule", chunk: "Chunk") -> str:
         return "'{}' constraint is not met".format(type(self).__name__)
 
 
@@ -82,7 +82,7 @@ class Chunk:
     def append_to(self, schedule: "Schedule"):
         for ctr in self.task.constraints.values():
             if not ctr.isvalid(schedule, self):
-                raise ConstraintError(ctr.get_error(schedule, self))
+                raise ConstraintError(ctr.geterror(schedule, self))
 
         if self.task in schedule.taskmap:
             schedule.taskmap[self.task].append(self)
